# ada-course-search-package

SSG Ada Course Search package for pypi

# Packaging the Project

## Package the Code

Execute `python3 -m build` in the terminal

## Upload to PyPI Distribution

Execute `python3 -m twine upload dist/*` in the terminal

## Install the package from PyPI

Execute pip install `ssg-ada-course-search` in the terminal

## Import the package

Execute `from course_search.course_search import search_for_courses` in IDE